@@ -46,7 +46,6 @@ SSO_Browser_Preference=""
 Sleep_Time_To_Wait_And_Get_Authocode=""
 Timer_Delay_to_Launch=""
 Server_AGENT=""
-Os_Independent=""
 Override_Ip_Settings=""
 # Class to run the windows commands. will have a run_command method
 class runWindowsCommand:
@@ -344,20 +343,6 @@ def prepPatchCreation():
         dest=basepth+"\\BluSync.exe"
         os.unlink(dest)
         shutil.copy(src, dest)
-    if(Os_Independent=="true"):
-        basepth = Config.get(CONST.SECTION_ASSEMBLE_PATCH, CONST.BASE_DIR)
-        src= basepth+"\\OsIndependent Agent\\BluSync.exe"
-        dest=basepth+"\\BluSync.exe"
-        os.unlink(dest)
-        shutil.copy(src, dest)
-        
-        src= basepth+"\\OsIndependent Agent\\Blusync_WindowsInstaller.iss"
-        dest=basepth+"\\Blusync_WindowsInstaller.iss"
-        os.unlink(dest)
-        shutil.copy(src, dest)
-        
-        
-        
     pause("check for untared files")
     #copyPatchCreationScripts()
     updateVDF()
@@ -496,7 +481,6 @@ def processInputParams():
     global Sleep_Time_To_Wait_And_Get_Authocode
     global Timer_Delay_to_Launch
     global Server_AGENT
-    global Os_Independent
     global Override_Ip_Settings
     printNicely("before reading config file..")
     try:
@@ -515,10 +499,9 @@ def processInputParams():
         HideAgent=config.get('config', 'HideAgent')
         Sleep_Time_To_Wait_And_Get_Authocode=config.get('config', 'Sleep_Time_To_Wait_And_Get_Authocode')
         Timer_Delay_to_Launch=config.get('config', 'Timer_Delay_to_Launch')
-        Os_Independent=config.get('config','Os_Independent')
         Server_AGENT=config.get('config', 'Server_AGENT')
         Override_Ip_Settings=config.get('config','Override_Ip_Settings')
-        if(cloudName=="" or EBMS_dom=="" or  MailLink=="" or Silent_NonSilent=="" or Non_Bruteforce_Agent=="" or versionNumber=="" or HideAgent=="" or Server_AGENT=="" or Os_Independent==""or Override_Ip_Settings==""):
+        if(cloudName=="" or EBMS_dom=="" or  MailLink=="" or Silent_NonSilent=="" or Non_Bruteforce_Agent=="" or versionNumber=="" or HideAgent=="" or Server_AGENT=="" or Override_Ip_Settings==""):
             printNicely("input values are empty so exit..", True)
             exit(1)
     except Exception as e:
@@ -638,12 +621,12 @@ def modifyFilesToPackage():
             changeBallonLabel = ["###Systray-Balloon-Label###","Parablu Server EPA"]
             changeTooltip = ["###Systray-Tooltip-Label###","Parablu Server EPA"]
             changeSuccessLabel  = ["###Success-Label###","You have successfully registered with Parablu Server EPA."]
-            changeArray = [changeCloudName, changeEBMSDOM,changeSubEBS, changeSubEBS1, changeMailLink ,changeSSOBrowserPreference,changeBallonLabel,changeTooltip,changeSuccessLabel]
+            changeArray = [changeCloudName, changeEBMSDOM,changeSubEBS, changeSubEBS1, changeMailLink ,changeSSOBrowserPreference,changeBallonLabel,changeTooltip,changeSuccessLabel,changeOverRideSettings]
         else:
             changeBallonLabel = ["###Systray-Balloon-Label###","Parablu EPA"]
             changeTooltip = ["###Systray-Tooltip-Label###","Parablu EPA"]
             changeSuccessLabel  = ["###Success-Label###","You have successfully registered with Parablu EPA."]
-            changeArray = [changeCloudName, changeEBMSDOM,changeSubEBS, changeSubEBS1, changeMailLink ,changeSSOBrowserPreference,changeBallonLabel,changeTooltip,changeSuccessLabel]
+            changeArray = [changeCloudName, changeEBMSDOM,changeSubEBS, changeSubEBS1, changeMailLink ,changeSSOBrowserPreference,changeBallonLabel,changeTooltip,changeSuccessLabel,changeOverRideSettings]
         sedEquiv(baseDir + CONST.CONF_TEMPLATE, baseDir + CONST.CONF_TEMPLATE_OUT, changeArray)
        # sedEquiv(baseDir + CONST.CONF_TEMPLATE, baseDir + CONST.CONF_TEMPLATE_OUT_FOR_SERVICE, changeArray)
         
@@ -669,14 +652,7 @@ def uploadSFX(patchDir, dtVerName):
         sftp.mkdir(remPath)
         # put the SXF file on the remote server
         localFile = patchDir + "\\Windows_"+versionNumber+"_"+CONST.LOCAL_EPA_PATH
-        if(Os_Independent=="true"):
-            remoteFile = remPath + "/Windows-OsIndependent_"+versionNumber+"_"+CONST.REM_EPA_PATH
-        else:
-            if(Server_AGENT=="serveragent"):
-                remoteFile = remPath + "/Windows-server_"+versionNumber+"_"+CONST.REM_EPA_PATH
-            else:
-                remoteFile = remPath + "/Windows_"+versionNumber+"_"+CONST.REM_EPA_PATH
-                
+        remoteFile = remPath + "/Windows_"+versionNumber+"_"+CONST.REM_EPA_PATH
             
         sftp.put(localFile, remoteFile)
         
@@ -734,13 +710,8 @@ def signSFX(patchDir):
     logFileName=logPath + CONST.LOG_FILE_NAME + tsToUse + CONST.LOG_FILE_EXT
     changeSignToolPath=[CONST.WIN_SIGN_TOOL_PATH_PAT, Config.get(CONST.SECTION_ASSEMBLE_PATCH, CONST.SRC_DIR)]
     changeWinInstallerPath=[CONST.WIN_INST_PATH_PAT, patchDir]
-    digicertFilePath=Config.get(CONST.SECTION_ASSEMBLE_PATCH, CONST.BASE_DIR)+"\\DigiCert\\DigicertKey.txt"
-    with open(digicertFilePath, 'r') as file:
-        data = file.read().replace('\n', '')
-    printNicely(data+"digicert key", True)
-    changeDigicertKey=[CONST.DIGICERT_KEY, data]
     # we first create the bldCMD bat file by updating the template file
-    sedEquiv(bldCMD+ CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath,changeDigicertKey])
+    sedEquiv(bldCMD+ CONST.TEMPLATE_EXT, bldCMD,[changeSignToolPath,changeWinInstallerPath])
     mycmd.runCommandWithArgs([bldCMD, versionNumber, CONST.REDIR ,logFileName ])
 
 
